==> paraview-v1.0.3.zip: paraview-v1.0.3/ParaView/KWCommon/XML/vtkXMLCameraWriter.cxx <==
/*=========================================================================

Copyright (c) 1998-2003 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkXMLCameraWriter.h"

#include "vtkObjectFactory.h"
#include "vtkCamera.h"
#include "vtkXMLDataElement.h"

vtkStandardNewMacro(vtkXMLCameraWriter);
vtkCxxRevisionMacro(vtkXMLCameraWriter, "1.2");

//----------------------------------------------------------------------------
char* vtkXMLCameraWriter::GetRootElementName()
{
  return "Camera";
}

//----------------------------------------------------------------------------
int vtkXMLCameraWriter::AddAttributes(vtkXMLDataElement *elem)
{
  if (!this->Superclass::AddAttributes(elem))
    {
    return 0;
    }

  vtkCamera *obj = vtkCamera::SafeDownCast(this->Object);
  if (!obj)
    {
    vtkWarningMacro(<< "The Camera is not set!");
    return 0;
    }

  elem->SetIntAttribute("ParallelProjection", obj->GetParallelProjection());

  elem->SetVectorAttribute("Position", 3, obj->GetPosition());

  elem->SetVectorAttribute("FocalPoint", 3, obj->GetFocalPoint());

  elem->SetVectorAttribute("ViewUp", 3, obj->GetViewUp());

  elem->SetVectorAttribute("ClippingRange", 3, obj->GetClippingRange());

  elem->SetDoubleAttribute("ViewAngle", obj->GetViewAngle());

  elem->SetDoubleAttribute("ParallelScale", obj->GetParallelScale());

  return 1;
}

==> paraview-v1.2.0.zip: paraview-v1.2.0/ParaView/KWCommon/XML/vtkXMLCameraWriter.cxx <==
/*=========================================================================

  Module:    vtkXMLCameraWriter.cxx

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkXMLCameraWriter.h"

#include "vtkObjectFactory.h"
#include "vtkCamera.h"
#include "vtkXMLDataElement.h"

vtkStandardNewMacro(vtkXMLCameraWriter);
vtkCxxRevisionMacro(vtkXMLCameraWriter, "1.3");

//----------------------------------------------------------------------------
char* vtkXMLCameraWriter::GetRootElementName()
{
  return "Camera";
}

//----------------------------------------------------------------------------
int vtkXMLCameraWriter::AddAttributes(vtkXMLDataElement *elem)
{
  if (!this->Superclass::AddAttributes(elem))
    {
    return 0;
    }

  vtkCamera *obj = vtkCamera::SafeDownCast(this->Object);
  if (!obj)
    {
    vtkWarningMacro(<< "The Camera is not set!");
    return 0;
    }

  elem->SetIntAttribute("ParallelProjection", obj->GetParallelProjection());

  elem->SetVectorAttribute("Position", 3, obj->GetPosition());

  elem->SetVectorAttribute("FocalPoint", 3, obj->GetFocalPoint());

  elem->SetVectorAttribute("ViewUp", 3, obj->GetViewUp());

  elem->SetVectorAttribute("ClippingRange", 3, obj->GetClippingRange());

  elem->SetDoubleAttribute("ViewAngle", obj->GetViewAngle());

  elem->SetDoubleAttribute("ParallelScale", obj->GetParallelScale());

  return 1;
}
